@@ -1,15 +1,15 @@
-# 
+#
 # This file is part of HTML-FormFu-ExtJS
-# 
+#
 # This software is Copyright (c) 2010 by Moritz Onken.
-# 
+#
 # This is free software, licensed under:
-# 
+#
 #   The (three-clause) BSD License
-# 
+#
 package HTML::FormFu::ExtJS::Element::File;
 BEGIN {
-  $HTML::FormFu::ExtJS::Element::File::VERSION = '0.076';
+  $HTML::FormFu::ExtJS::Element::File::VERSION = '0.077';
 }
 
 use base "HTML::FormFu::ExtJS::Element::Text";
@@ -22,7 +22,7 @@ sub render {
 	my $class = shift;
 	my $self = shift;
 	my $super = $class->SUPER::render($self);
-	$self->form->attrs_xml->{fileUpload} = \1;
+	$self->form->attrs->{fileUpload} = \1;
 	return { %{$super}, inputType => "file", value => undef };
 	
 	
@@ -40,7 +40,7 @@ HTML::FormFu::ExtJS::Element::File
 
 =head1 VERSION
 
-version 0.076
+version 0.077
 
 =head1 DESCRIPTION
 
@@ -65,7 +65,7 @@ under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-  Moritz Onken <onken@netcubed.de>
+Moritz Onken <onken@netcubed.de>
 
 =head1 COPYRIGHT AND LICENSE
 
